**********************************************************************
*
* Program Name: HAMENC1.ASM (Hamming Encoder #1 - Table Look-up)
* Revision: 1.00
* Date: January 21,1993
*
* Written By: Mark Glenewinkel
*             Motorola CSIC Applications
*
* Assembled Under: P&E Microcomputer Systems IASM08
*
*       *********************************
*       *       Revision History        *
*       *********************************
*
*       Rev     0.50    12/15/92        M.A. McQuilken
*                       HC05 version to be translated to HC08 code
*
*       Rev     0.60    01/21/93        M.R. Glenewinkel
*                       Added more comments
*
*       Rev     1.00    01/22/93        M.R. Glenewinkel
*                       HC08 version
*
**********************************************************************
*
* Program Description:
*       This routine will encode a four-bit info word into a (7,4)
*       Hamming encoding codeword.
*
*       This source code is an example of using a table look-up
*       method to encode a four bit info word to a seven bit code
*       word. For a more detailed description of the process of error
*       control codes and Hamming codes in particular, please
*       refer to Motorola Application Note 1221.
*       This routine consists of only one instruction, a
*       look-up table fetch, where the encoding has been already
*       done and inserted into this look-up table.
*
*       "info word" is the word you want to encode
*       "codeword" is an encoded info word
*
* TASK DATA:
*  Input Variables      Output Variables        Description
*  ----------------     -----------------       -------------
*  X                                            Enter routine with
*                                                X-reg=LSN of info
*                                                word.
*                       ACCA                    Leave routine with
*                                                7-bit codeword in here
*
*
* LOCAL DATA:
*  Input Variables      Output Variables        Description
*  ----------------     -----------------       -------------
*  ACCA                                         Misc. computational
*                                                use.
*
**********************************************************************
*
* Register and Variable Equates
*
*       None
*
**********************************************************************
*
* Memory
*
*       None
*
**********************************************************************

                ORG     $1000           ;beginning of program area
START           EQU     *

**********************************************************************

* Main Routine

HAMENC1         lda     CodeWords,X     ;ACCA <- (CodeWords+X)
                                        ;X contains the offset
                                        ; from CodeWords

DONE		    nop			    ;done !!!
		    bra	DONE

**********************************************************************

* Tables

                ORG     $2000
CodeWords       FCB     %00000000
                FCB     %01010001
                FCB     %01110010
                FCB     %00100011
                FCB     %00110100
                FCB     %01100101
                FCB     %01000110
                FCB     %00010111
                FCB     %01101000
                FCB     %00111001
                FCB     %00011010
                FCB     %01001011
                FCB     %01011100
                FCB     %00001101
                FCB     %00101110
                FCB     %01111111

**********************************************************************

* Vector Setup

                ORG     $FFFE
                DW      START           ;set up reset vector

**********************************************************************
