**********************************************************************
*
* Program Name: TDPACK.ASM (Time Diversity Pack and UnPack)
*
* Revision: 1.00
* Date: January 20,1993
*
* Written By: Mark Glenewinkel
*             Motorola CSIC Applications
*
* Assembled Under: P&E Microcomputer Systems IASM08
*
*       *********************************
*       *       Revision History        *
*       *********************************
*
*       Rev     0.50    12/15/92        M.A. McQuilken
*                       HC05 version to be translated to HC08 code
*
*       Rev     0.60    01/20/93        M.R. Glenewinkel
*                       Fixed logic bugs
*
*       Rev     1.00    01/22/93        M.R. Glenewinkel
*                       HC08 version
*
**********************************************************************
*
* Program Description:
*
*       This routine will take a matrix that is 8 bits wide and 8
*       bytes deep and transpose the matrix so that the first row
*       becomes the 1st column, the second row becomes the 2nd
*       column...the last row becomes the 8th column. This is to
*       distribute data bits over several byte transfers so that no
*       channel errors "wipe out" a complete single byte...only
*       individual bits within each source byte will be hit (if the
*       channel fades are "deep" and not frequent). It is expected
*       that the complementary process of "unpacking" (un-transposing)
*       on the receive end must be done to recover the data as it was
*       intended. By executing another transpose on the data, the data
*       will be "unpacked" to its original form.
*
*       As stated above, this routine transposes a matrix consisting
*       of 64 bits. It does this by left shifting each bit of one
*       source row into its corresponding destination column. After
*       all eight bits of the source are shifted to the destination
*       column, the next source byte is left shifted to the next
*       destination column. This entire process is repeated until
*       all eight source bytes and destination bytes have had all of
*       their bits moved.
*
* Task Data:
*
*  Input Variables      Output Variables        Description
*  ----------------     -----------------       -------------
*  SrcBuffer                                    Eight byte buffer for
*                                                info that is to be
*                                                transposed before
*                                                transmission on
*                                                channel.
*                       DestBuffer              Eight byte buffer that
*                                                contains transposed
*                                                version of data
*                                                previously contained
*                                                in SrcBuffer.
*
*
* LOCAL DATA:
*  Input Variables      Output Variables        Description
*  ----------------     -----------------       -------------
*  BitCounter           BitCounter              Keeps track of the
*                                                bits being shifted
*                                                from the source
*                                                buffer
*  DestCntr             DestCntr                Current byte location
*                                                in destination
*                                                buffer.
*  SrcCntr              SrcCntr                 Current byte location
*                                                in source buffer.
*  ACCA                 ACCA                    Misc. computational
*                                                use.
*  X                    X                       Misc. computational
*                                                use.
*
**********************************************************************
*
* Register and Variable Equates
*
*       None
*
**********************************************************************
*
* Memory
*
                ORG     $50
BitCounter      RMB     1
DestCntr        RMB     1
SrcCntr         RMB     1
SrcBuffer       EQU     *
SrcBufrTop      RMB     8
DestBuffer      EQU     *
DestBufrTop     RMB     8
*
**********************************************************************

                ORG     $1000           ;beginning of program area
START           EQU     *

**********************************************************************

* Main Routine

* Initialization of the variables must occur before the data can
* be manipulated.

TDPack          mov     #SrcBufrTop,SrcCntr
                                        ;the starting place for
                                        ; source data manipulation

* Although the next couple of lines could also be considered
* basic workspace initialization, the initialization occurs
* every 8-bits of source data manipulation:

SetUpDestPntr   mov     #DestBufrTop,DestCntr
                                        ;these two lines allow us to
                                        ; point to DestBufrTop


* A separate bit counter is maintained to ease the hassle of
* evaluating the loop point for the 8 bits:

                mov     #8,BitCounter   ;(BitCounter) <- #8


* At this point, the inner loop (which counts the bits shifted out
* of the source buffer) begins.

InnerLoop       ldx     SrcCntr         ;SrcCntr contains the
                                        ; location of the current
                                        ; byte to be shifted
                                        ; out of the source buffer.
                lsl     ,X              ;this moves from source
                                        ; data buffer
                                        ; into the carry bit.

* Time to move the data into the destination buffer:

                ldx     DestCntr        ;like the SrcCntr, this
                                        ; pointer contains the
                                        ; address of the destination
                                        ; byte.
                rol     ,X              ;move data from carry into
                                        ; destination byte.

* Here's where we determine if we've shifted enough data bits:

                inc     DestCntr        ;proceed to next
                                        ; destination byte
                dbnz    BitCounter,InnerLoop
                                        ;branch if we've not moved
                                        ; eight bits in eight of
                                        ; the destination bytes.


* If we've made it here, then we've moved an eight bit chunk of the
* source buffer. These next few lines of code determine the actual
* value of the pointer into the source buffer. It also contains
* the test for completion of movement into the destination buffer:

                inc     SrcCntr         ;update counter
                lda     SrcCntr         ;get counter in ACCA

                cmp     #SrcBufrTop+8   ;test
                bne     SetUpDestPntr   ;branch if we haven't
                                        ; moved everything.

DONE            nop                     ;done !!!
                bra     DONE

**********************************************************************

* Vector Setup

                ORG     $FFFE
                DW      START           ;set up reset vector

**********************************************************************

